@@ -337,7 +337,7 @@ class Helper:
   print_check_group_by = """\n
 "Group By" Syntax:
   stream.group_by( name = "name", \t\t\t\t => optional
-                   group_by = ["field_1", "field_2", ...],
+                   fields = ["field_1", "field_2", ...],
                    emits = ["stream_1", "stream_2", ...], \t => optional for single output stream
                    begin_group = begin_group_function
                    aggregate = aggregate_function
