@@ -97,7 +97,7 @@ class Stream:
 
     return output_streams
 
-  def join_with(self, name=None, rh_stream=None, emits=None, fields=None, options=None):
+  def join_with(self, name=None, stream=None, emits=None, fields=None, options=None):
     node = Join(name, emits, fields, options)
     Helper.check_name("join", node._name, self._app._names)
     Helper.check_join(node)
@@ -110,7 +110,7 @@ class Stream:
       Helper.write_node_to_file(node_hash, self._app._info_file)
       arc_hash1 = {"name":self._name, "origin":self._previous_node_name, "dest":node._name, "left":1}
       Helper.write_arc_to_file(arc_hash1, self._app._info_file)
-      arc_hash2 = {"name":rh_stream._name, "origin":rh_stream._previous_node_name, "dest":node._name, "right":1}
+      arc_hash2 = {"name":stream._name, "origin":stream._previous_node_name, "dest":node._name, "right":1}
       Helper.write_arc_to_file(arc_hash2, self._app._info_file)
 
     output_stream = self.__class__(node._emits[0], self._app, node._name)
